@@ -5,6 +5,8 @@ SCRIPT_LOCATION=$(dirname $(readlink -f "$0"))
 
 . "${SCRIPT_LOCATION}"/../scripts/dependency_sources.sh
 
+adjust_sources "mingw"
+
 WIN_VER="0x0501" #https://msdn.microsoft.com/en-us/library/windows/desktop/aa383745%28v=vs.85%29.aspx
 MAKEOPTS="-j 4"
 
@@ -45,7 +47,7 @@ LIBTOOL_ARCHIVE="${_LIBTOOL_ARCHIVE}"
 
 LIBICONV_ARCHIVE="${_LIBICONV_ARCHIVE}"
 LIBXML2_ARCHIVE="${_LIBXML2_ARCHIVE}"
-#GETTEXT_ARCHIVE="${_GETTEXT_ARCHIVE}" # Disable NLS.
+GETTEXT_ARCHIVE="${_GETTEXT_ARCHIVE}" # Enable NLS.
 
 LIBCURL_ARCHIVE="${_LIBCURL_ARCHIVE}"
 OPENSSL_ARCHIVE="${_OPENSSL_ARCHIVE}"
@@ -335,6 +337,10 @@ elif [ ! -z "${LIBISDS_GIT}" ]; then
 
 	LINTL=""
 	NLS="--disable-nls"
+	if [ ! -z "${GETTEXT_ARCHIVE}" ]; then
+		LINTL="-lintl"
+		NLS=""
+	fi
 	CONFOPTS="${CONFOPTS} ${NLS}"
 
 	cat configure.ac | sed -e 's/AC_FUNC_MALLOC//g' > nomalloc_configure.ac
