@@ -49,26 +49,20 @@
 #define DLG_ISDS_KEEPALIVE_MS 180000 // 3 min dialog isds ping timer period
 #define MAX_ATTACHMENT_SIZE_MB 20
 #define MAX_ATTACHMENT_SIZE_BYTES 20000000 // 20MB
+#define MAX_ATTACHMENT_FILES 900 // Number of attachment files is throttled at 900
 #define TIMER_STATUS_TIMEOUT_MS 5000 // 5s will message in status bar shown
 #define TIMER_MARK_MSG_READ_MS 5000 /* Mark message as read after 5 seconds. */
 
+#define SUPPORT_MAIL "datove-schranky@labs.nic.cz"
 #define CZ_NIC_URL "https://www.nic.cz"
-#define DATOVKA_ONLINE_HELP_URL "https://gitlab.labs.nic.cz/labs/qdatovka/wikis/manual"
+#define DATOVKA_ONLINE_HELP_URL "https://secure.nic.cz/files/datove_schranky/redirect/prirucka.html"
+#define DATOVKA_FAQ_URL "https://secure.nic.cz/files/datove_schranky/redirect/faq.html"
 #define DATOVKA_HOMEPAGE_URL "https://labs.nic.cz/cs/datovka.html"
 #define DATOVKA_CHECK_NEW_VERSION_URL "https://secure.nic.cz/files/datove_schranky/Version"
 #define DATOVKA_DOWNLOAD_URL "https://labs.nic.cz/cs/datovka.html"
 #define PWD_EXPIRATION_NOTIFICATION_DAYS 7 // show expiration date dialog before xx days
 
 
-/* return values of Datovka login methods */
-typedef enum {
-	USER_NAME = 0,
-	CERTIFICATE = 1,
-	USER_CERTIFICATE = 2,
-	HOTP = 3,
-	TOTP = 4
-} LoginMethodsIndex;
-
 /* return values of Datovka message state */
 enum MessageProcessState {
 	UNSETTLED = 0,
