@@ -29,6 +29,7 @@
 
 #include "dlg_correspondence_overview.h"
 #include "src/io/filesystem.h"
+#include "src/models/accounts_model.h"
 #include "src/settings/preferences.h"
 
 
@@ -93,7 +94,7 @@ DlgCorrespondenceOverview::DlgCorrespondenceOverview(const MessageDbSet &dbSet,
 void DlgCorrespondenceOverview::msgStateChanged(int state)
 /* ========================================================================= */
 {
-	(void) state; /* Unused. */
+	Q_UNUSED(state);
 
 	if ((!this->sentCheckBox->isChecked()) &&
 	    (!this->receivedCheckBox->isChecked())) {
@@ -111,7 +112,7 @@ void DlgCorrespondenceOverview::msgStateChanged(int state)
 void DlgCorrespondenceOverview::dateCalendarsChange(const QDate &date)
 /* ========================================================================= */
 {
-	(void) date; // not used
+	Q_UNUSED(date);
 
 	this->toCalendarWidget->setMinimumDate(
 	    this->fromCalendarWidget->selectedDate());
@@ -342,7 +343,12 @@ bool DlgCorrespondenceOverview::exportMessagesToHtml(
 	}
 
 	QTextStream f(&fout);
-	/* Generate CSV header. */
+	/*
+	 * Always use UTF-8 for this HTML file as this encoding is hard-wired
+	 * into its header.
+	 */
+	f.setCodec("UTF-8");
+	/* Generate HTML header. */
 	f << "<!DOCTYPE html\n"
 	    "   PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\""
 	    "\"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n"
@@ -515,10 +521,10 @@ void DlgCorrespondenceOverview::exportData(void)
 				            overviewFileName)),
 				    QMessageBox::Ok);
 				tmpMsg += "<b>0</b> " + tr("correspondence "
-				"overview file was exported to CVS.") +"<br/>";
+				"overview file was exported to CSV.") +"<br/>";
 			} else {
 				tmpMsg += "<b>1</b> " + tr("correspondence "
-				"overview file was exported to CVS.") +"<br/>";
+				"overview file was exported to CSV.") +"<br/>";
 			}
 		}
 	} else {
