@@ -169,7 +169,7 @@ void DlgDsSearch::setFirtsColumnActive(void)
 void DlgDsSearch::pingIsdsServer(void)
 /* ========================================================================= */
 {
-	if (isdsSessions.isConnectedToIsds(m_userName)) {
+	if (globIsdsSessions.isConnectedToIsds(m_userName)) {
 		qDebug() << "Connection to ISDS is alive :)";
 	} else {
 		qDebug() << "Connection to ISDS is dead :(";
@@ -213,10 +213,8 @@ void DlgDsSearch::checkInputFields(void)
 	case 2:
 		this->iCLineEdit->setEnabled(true);
 		this->labelName->setText(tr("Name:"));
-		this->labelName->setToolTip(tr("Enter PFO last name or "
-		    "firm name."));
-		this->nameLineEdit->setToolTip(tr("Enter PFO last name or "
-		    "firm name."));
+		this->labelName->setToolTip(tr("Enter PFO last name or company name."));
+		this->nameLineEdit->setToolTip(tr("Enter PFO last name or company name."));
 		if (m_showInfoLabel) {
 			this->infoLabel->show();
 		} else {
@@ -358,7 +356,7 @@ void DlgDsSearch::searchDataBox(void)
 	delete task;
 	isds_DbOwnerInfo_free(&ownerInfo);
 
-	session = isdsSessions.session(m_userName);
+	session = globIsdsSessions.session(m_userName);
 	if (NULL == session) {
 		Q_ASSERT(0);
 		goto fail;
