@@ -82,7 +82,7 @@ namespace AccntinfTbl {
 	{"pnMiddleName",           {DB_TEXT, QObject::tr("Middle name")}},
 	{"pnLastName",             {DB_TEXT, QObject::tr("Surname")}},
 	{"pnLastNameAtBirth",      {DB_TEXT, QObject::tr("Surname at birth")}},
-	{"firmName",               {DB_TEXT, QObject::tr("Firm name")}},
+	{"firmName",               {DB_TEXT, QObject::tr("Company name")}},
 	{"biDate",                 {DB_DATE, QObject::tr("Date of birth")}},
 	{"biCity",                 {DB_TEXT, QObject::tr("City of birth")}},
 	{"biCounty",               {DB_TEXT, QObject::tr("County of birth")}},
@@ -157,7 +157,7 @@ namespace UserinfTbl {
 	{"adState",                {DB_TEXT, QObject::tr("State")}},
 	{"biDate",                 {DB_DATE, QObject::tr("Date of birth")}},
 	{"ic",                     {DB_INTEGER, QObject::tr("IČ")}},
-	{"firmName",               {DB_TEXT, QObject::tr("Firm name")}},
+	{"firmName",               {DB_TEXT, QObject::tr("Company name")}},
 	{"caStreet",               {DB_TEXT, QObject::tr("Street of residence")}},
 	{"caCity",                 {DB_TEXT, QObject::tr("City of residence")}},
 	{"caZipCode",              {DB_TEXT, QObject::tr("Zip code")}},
@@ -271,14 +271,14 @@ namespace MsgsTbl {
 	{"dmRecipientOrgUnit",    {DB_TEXT, ""}},
 	{"dmRecipientOrgUnitNum", {DB_TEXT, ""}},
 	{"dmToHands",             {DB_TEXT, QObject::tr("To hands")}},
-	{"dmAnnotation",          {DB_TEXT, QObject::tr("Title")}},
+	{"dmAnnotation",          {DB_TEXT, QObject::tr("Subject")}},
 	{"dmRecipientRefNumber",  {DB_TEXT, QObject::tr("Your reference number")}},
 	{"dmSenderRefNumber",     {DB_TEXT, QObject::tr("Our reference number")}},
 	{"dmRecipientIdent",      {DB_TEXT, QObject::tr("Your file mark")}},
 	{"dmSenderIdent",         {DB_TEXT, QObject::tr("Our file mark")}},
 	{"dmLegalTitleLaw",       {DB_TEXT, QObject::tr("Law")}},
 	{"dmLegalTitleYear",      {DB_TEXT, QObject::tr("Year")}},
-	{"dmLegalTitleSect",      {DB_TEXT, QObject::tr("Selection")}},
+	{"dmLegalTitleSect",      {DB_TEXT, QObject::tr("Section")}},
 	{"dmLegalTitlePar",       {DB_TEXT, QObject::tr("Paragraph")}},
 	{"dmLegalTitlePoint",     {DB_TEXT, QObject::tr("Letter")}},
 	{"dmPersonalDelivery",    {DB_BOOLEAN, QObject::tr("Personal delivery")}},
