@@ -26,7 +26,6 @@
 #include <cstring> /* memset(3) */
 #include <QDebug>
 #include <QFile>
-#include <QInputDialog>
 #include <QObject>
 
 #include "isds_sessions.h"
@@ -36,7 +35,7 @@
 #include "src/settings/preferences.h"
 
 
-GlobIsdsSessions isdsSessions;
+IsdsSessions globIsdsSessions;
 
 
 /* ========================================================================= */
@@ -115,7 +114,7 @@ void logCallback(isds_log_facility facility, isds_log_level level,
 
 
 /* ========================================================================= */
-GlobIsdsSessions::GlobIsdsSessions(void)
+IsdsSessions::IsdsSessions(void)
 /* ========================================================================= */
     : m_sessions()
 {
@@ -146,7 +145,7 @@ GlobIsdsSessions::GlobIsdsSessions(void)
 
 
 /* ========================================================================= */
-GlobIsdsSessions::~GlobIsdsSessions(void)
+IsdsSessions::~IsdsSessions(void)
 /* ========================================================================= */
 {
 	isds_error status;
@@ -175,7 +174,7 @@ GlobIsdsSessions::~GlobIsdsSessions(void)
 
 
 /* ========================================================================= */
-bool GlobIsdsSessions::holdsSession(const QString &userName) const
+bool IsdsSessions::holdsSession(const QString &userName) const
 /* ========================================================================= */
 {
 	return 0 != m_sessions.value(userName, 0);
@@ -186,7 +185,7 @@ bool GlobIsdsSessions::holdsSession(const QString &userName) const
 /*
  * Is connect to databox given by account index
  */
-bool GlobIsdsSessions::isConnectedToIsds(const QString &userName)
+bool IsdsSessions::isConnectedToIsds(const QString &userName)
 /* ========================================================================= */
 {
 	isds_error ping_status;
@@ -210,7 +209,7 @@ bool GlobIsdsSessions::isConnectedToIsds(const QString &userName)
 /*
  * Creates new session.
  */
-struct isds_ctx * GlobIsdsSessions::createCleanSession(const QString &userName,
+struct isds_ctx *IsdsSessions::createCleanSession(const QString &userName,
     unsigned int connectionTimeoutMs)
 /* ========================================================================= */
 {
@@ -255,7 +254,7 @@ fail:
  * Set time-out in milliseconds to session associated to
  *     user name.
  */
-bool GlobIsdsSessions::setSessionTimeout(const QString &userName,
+bool IsdsSessions::setSessionTimeout(const QString &userName,
     unsigned int timeoutMs)
 /* ========================================================================= */
 {
@@ -283,7 +282,7 @@ bool GlobIsdsSessions::setSessionTimeout(const QString &userName,
 /*
  * Returns associated session.
  */
-struct isds_ctx * GlobIsdsSessions::session(const QString &userName) const
+struct isds_ctx * IsdsSessions::session(const QString &userName) const
 /* ========================================================================= */
 {
 	return m_sessions.value(userName, NULL);
@@ -502,7 +501,8 @@ isds_error isdsLoginUserCertPwd(struct isds_ctx *isdsSession,
  */
 isds_error isdsLoginUserOtp(struct isds_ctx *isdsSession,
     const QString &userName, const QString &pwd, bool testingSession,
-    const QString &otpMethod, const QString &otpCode, isds_otp_resolution &res)
+    enum AcntSettings::LogInMethod otpMethod, const QString &otpCode,
+    isds_otp_resolution &res)
 /* ========================================================================= */
 {
 	Q_ASSERT(0 != isdsSession);
@@ -522,7 +522,7 @@ isds_error isdsLoginUserOtp(struct isds_ctx *isdsSession,
 	}
 	memset(otp, 0, sizeof(struct isds_otp));
 
-	if (otpMethod == LIM_HOTP) {
+	if (otpMethod == AcntSettings::LIM_UNAME_PWD_HOTP) {
 		otp->method = OTP_HMAC;
 	} else {
 		otp->method = OTP_TIME;
