@@ -34,10 +34,10 @@
 #include <QObject>
 #include <QPair>
 #include <QStringList>
-#include <QSqlDatabase>
 #include <QString>
 #include <QVector>
 
+#include "src/io/sqlite/db.h"
 #include "src/models/files_model.h"
 #include "src/models/messages_model.h"
 
@@ -54,7 +54,7 @@ enum Sorting {
 /*!
  * @brief Encapsulates message database.
  */
-class MessageDb : public QObject {
+class MessageDb : public SQLiteDb {
 
 public:
 	/*!
@@ -220,58 +220,12 @@ public:
 		}
 	};
 
-	MessageDb(const QString &dbDriverType, const QString &connectionName,
-	    QObject *parent = 0);
-	virtual ~MessageDb(void);
-
-	static
-	const QString memoryLocation;
-
 	/*!
-	 * @brief Get file name.
+	 * @brief Constructor.
 	 *
-	 * @return Database file name.
+	 * @param[in] connectionName Connection name.
 	 */
-	QString fileName(void) const;
-
-	/*!
-	 * @brief Begin a transaction.
-	 *
-	 * @return True on success.
-	 */
-	bool beginTransaction(void);
-
-	/*!
-	 * @brief End transaction.
-	 */
-	bool commitTransaction(void);
-
-	/*!
-	 * @brief Begin named transaction.
-	 *
-	 * @param[in] savePointName  Name of the save point.
-	 * @return True on success.
-	 */
-	bool savePoint(const QString &savePointName);
-
-	/*!
-	 * @brief End named transaction.
-	 *
-	 * @param[in] savePointName  Name of the save point.
-	 * @return True on success.
-	 */
-	bool releaseSavePoint(const QString &savePointName);
-
-	/*!
-	 * @brief Roll back transaction.
-	 *
-	 * @param[in] savePointName  Name of the save point.
-	 * @return True on success.
-	 *
-	 * @note If no save-point name is supplied then a complete roll-back is
-	 *     performed.
-	 */
-	bool rollbackTransaction(const QString &savePointName = QString());
+	explicit MessageDb(const QString &connectionName);
 
 	/*!
 	 * @brief Generate information for reply dialogue.
@@ -345,6 +299,15 @@ public:
 	QString envelopeInfoHtmlToPdf(qint64 dmId,
 	    const QString &dbType) const;
 
+	/*!
+	 * @brief Return message file list HTML to be used to generate a PDF.
+	 *
+	 * @param[in] dmId    Message identifier.
+	 * @return HTML formatted string generated from message file db.
+	 *     Empty string is returned on error.
+	 */
+	QString fileListHtmlToPdf(qint64 dmId) const;
+
 	/*!
 	 * @brief Return message delivery info HTML to be used to generate
 	 *     a PDF.
@@ -697,52 +660,38 @@ public:
 	   const QString &year);
 
 protected: /* These function are used from within a database container. */
-	/*!
-	 * @brief Attaches a database file to opened database.
-	 *
-	 * @param[in,out] query          Query to work with.
-	 * @param[in]     attachFileName File containing database to be attached.
-	 * @return False on error.
-	 */
-	static
-	bool attachDb2(QSqlQuery &query, const QString &attachFileName);
-
-	/*!
-	 * @brief Detaches attached database file from opened database.
-	 *
-	 * @param[in,out] query Query to work with.
-	 * @return False on error.
-	 */
-	static
-	bool detachDb2(QSqlQuery &query);
-
 	/*!
 	 * @brief Return all received messages model.
 	 *
+	 * @param[in] appendedCols List of names for added empty columns.
 	 * @return Pointer to model, 0 on failure.
 	 *
 	 * @note The model must not be freed.
 	 */
-	QAbstractTableModel * msgsRcvdModel(void);
+	QAbstractTableModel *msgsRcvdModel(const QStringList &appendedCols);
 
 	/*!
 	 * @brief Return received messages within past 90 days.
 	 *
+	 * @param[in] appendedCols List of names for added empty columns.
 	 * @return Pointer to model, 0 on failure.
 	 *
 	 * @note The model must not be freed.
 	 */
-	QAbstractTableModel * msgsRcvdWithin90DaysModel(void);
+	QAbstractTableModel *msgsRcvdWithin90DaysModel(
+	    const QStringList &appendedCols);
 
 	/*!
 	 * @brief Return received messages within given year.
 	 *
-	 * @param[in] year  Year number.
+	 * @param[in] year         Year number.
+	 * @param[in] appendedCols List of names for added empty columns.
 	 * @return Pointer to model, 0 on failure.
 	 *
 	 * @note The model must not be freed.
 	 */
-	QAbstractTableModel * msgsRcvdInYearModel(const QString &year);
+	QAbstractTableModel *msgsRcvdInYearModel(const QString &year,
+	    const QStringList &appendedCols);
 
 	/*!
 	 * @brief Return list of years (strings) in database.
@@ -786,30 +735,35 @@ protected: /* These function are used from within a database container. */
 	/*!
 	 * @brief Return all sent messages model.
 	 *
+	 * @param[in] appendedCols List of names for added empty columns.
 	 * @return Pointer to model, 0 on failure.
 	 *
 	 * @note The model must not be freed.
 	 */
-	QAbstractTableModel * msgsSntModel(void);
+	QAbstractTableModel *msgsSntModel(const QStringList &appendedCols);
 
 	/*!
 	 * @brief Return sent messages within past 90 days.
 	 *
+	 * @param[in] appendedCols List of names for added empty columns.
 	 * @return Pointer to model, 0 on failure.
 	 *
 	 * @note The model must not be freed.
 	 */
-	QAbstractTableModel * msgsSntWithin90DaysModel(void);
+	QAbstractTableModel *msgsSntWithin90DaysModel(
+	    const QStringList &appendedCols);
 
 	/*!
 	 * @brief Return sent messages within given year.
 	 *
-	 * @param[in] year  Year number.
+	 * @param[in] year         Year number.
+	 * @param[in] appendedCols List of names for added empty columns.
 	 * @return Pointer to model, 0 on failure.
 	 *
 	 * @note The model must not be freed.
 	 */
-	QAbstractTableModel * msgsSntInYearModel(const QString &year);
+	QAbstractTableModel *msgsSntInYearModel(const QString &year,
+	    const QStringList &appendedCols);
 
 	/*!
 	 * @brief Set message read locally for all received messages.
@@ -940,6 +894,13 @@ protected: /* These function are used from within a database container. */
 	    const QString &dmDeliveryTime, const QString &dmAcceptanceTime,
 	    enum MessageDirection msgDirect) const;
 
+	/*!
+	 * @brief Get message envelope data from id.
+	 *
+	 * @return message data for message id.
+	 */
+	SoughtMsg msgsGetMsgDataFromId(const qint64 msgId) const;
+
 	/*!
 	 * @brief Test if imported message is relevent to account db.
 	 *
@@ -958,11 +919,6 @@ protected: /* These function are used from within a database container. */
 	 */
 	bool openDb(const QString &fileName, bool createMissing = true);
 
-	/*!
-	 * @brief Close database file.
-	 */
-	void closeDb(void);
-
 	/*!
 	 * @brief Copy db.
 	 *
@@ -988,37 +944,34 @@ protected: /* These function are used from within a database container. */
 	 */
 	bool reopenDb(const QString &newFileName);
 
-	/*!
-	 * @brief Perform a db integrity check.
-	 *
-	 * @return False if check fails.
-	 */
-	bool checkDb(bool quick);
-
-protected:
 	/*!
 	 * @brief Query received messages within past 90 days.
 	 *
-	 * @param[in,out] query Query already assigned to a database.
+	 * @param[in,out] query        Query already assigned to a database.
+	 * @param[in]     appendedCols List of names for added empty columns.
 	 * @return True on success.
 	 */
-	bool msgsRcvdWithin90DaysQuery(QSqlQuery &query);
+	bool msgsRcvdWithin90DaysQuery(QSqlQuery &query,
+	    const QStringList &appendedCols);
 
 	/*!
 	 * @brief Query received messages within past 90 days.
 	 *
-	 * @param[in,out] query Query already assigned to a database.
+	 * @param[in,out] query        Query already assigned to a database.
+	 * @param[in]     appendedCols List of names for added empty columns.
 	 * @return True on success.
 	 */
-	bool msgsSntWithin90DaysQuery(QSqlQuery &query);
+	bool msgsSntWithin90DaysQuery(QSqlQuery &query,
+	    const QStringList &appendedCols);
 
-	QSqlDatabase m_db; /*!< Message database. */
 	DbMsgsTblModel m_sqlMsgsModel; /*!< Model of displayed messages. */
 
 private:
 	static
 	const QVector<QString> msgPrintedAttribs;
 	static
+	const QVector<QString> msgDeliveryBoolAttribs;
+	static
 	const QVector<QString> msgStatus;
 	static
 	const QVector<QString> fileItemIds;
@@ -1036,11 +989,12 @@ private:
 	bool addDmtypeColumn(void);
 
 	/*!
-	 * @brief Create empty tables if tables do not already exist.
+	 * @brief Returns list of tables.
 	 *
-	 * @return True on success.
+	 * @return List of pointers to tables.
 	 */
-	bool createEmptyMissingTables(void);
+	static
+	QList<class SQLiteTbl *> listOfTables(void);
 
 	/*!
 	 * @brief This method ensures that the process_state table
