@@ -61,8 +61,7 @@ bool MessageDbSet::openLocation(const QString &newLocDir,
 	QStringList matchingFiles;
 
 	/* New location must exist. */
-	QDir dir(newLocDir);
-	if (!dir.exists()) {
+	if (!QDir(newLocDir).exists()) {
 		logErrorNL("Directory '%s' does not exist.\n",
 		    newLocDir.toUtf8().constData());
 		return false;
@@ -126,7 +125,7 @@ bool MessageDbSet::openLocation(const QString &newLocDir,
 		    fileName, organisation);
 
 		if (secondaryKey.isNull()) {
-			logErrorNL("Failed obtaining secondary key from file name '%s'.",
+			logErrorNL("Failed to obtain secondary key from file name '%s'.",
 			    fileName.toUtf8().constData());
 			return false;
 		}
@@ -145,7 +144,7 @@ bool MessageDbSet::openLocation(const QString &newLocDir,
 
 			db = _accessMessageDb(secondaryKey, false);
 			if (db == NULL) {
-				logErrorNL("Failed opening database file '%s'.",
+				logErrorNL("Failed to open database file '%s'.",
 				    fileName.toUtf8().constData());
 				/* TODO -- How can be this operation aborted? */
 			}
@@ -159,7 +158,7 @@ bool MessageDbSet::openLocation(const QString &newLocDir,
 		if (db == NULL) {
 			QString fileName(constructDbFileName(m_locDir,
 			    m_primaryKey, secKey, m_testing, m_organisation));
-			logErrorNL("Failed opening database file '%s'.",
+			logErrorNL("Failed to open database file '%s'.",
 			    fileName.toUtf8().constData());
 			return false;
 		}
@@ -174,6 +173,12 @@ bool MessageDbSet::copyToLocation(const QString &newLocDir)
 		return false;
 	}
 
+	if (!QDir(newLocDir).exists()) {
+		logErrorNL("Directory '%s' does not exist.\n",
+		    newLocDir.toUtf8().constData());
+		return false;
+	}
+
 	bool sucessfullyCopied = true;
 	QList< QPair<QString, MessageDb *> > oldLocations;
 	QList<QString> newLocations;
@@ -221,6 +226,12 @@ bool MessageDbSet::moveToLocation(const QString &newLocDir)
 		return false;
 	}
 
+	if (!QDir(newLocDir).exists()) {
+		logErrorNL("Directory '%s' does not exist.\n",
+		    newLocDir.toUtf8().constData());
+		return false;
+	}
+
 	bool sucessfullyCopied = true;
 	QList< QPair<QString, MessageDb *> > oldLocations;
 	QList<QString> newLocations;
@@ -275,6 +286,12 @@ bool MessageDbSet::reopenLocation(const QString &newLocDir,
 		return false;
 	}
 
+	if (!QDir(newLocDir).exists()) {
+		logErrorNL("Directory '%s' does not exist.\n",
+		    newLocDir.toUtf8().constData());
+		return false;
+	}
+
 	for (QMap<QString, MessageDb *>::iterator i = this->begin();
 	     i != this->end(); ++i) {
 		MessageDb *db = i.value();
@@ -306,7 +323,7 @@ bool MessageDbSet::reopenLocation(const QString &newLocDir,
 		if (db == NULL) {
 			QString fileName(constructDbFileName(m_locDir,
 			    m_primaryKey, secKey, m_testing, m_organisation));
-			logErrorNL("Failed opening database file '%s'.",
+			logErrorNL("Failed to open database file '%s'.",
 			    fileName.toUtf8().constData());
 			return false;
 		}
@@ -337,7 +354,7 @@ bool MessageDbSet::deleteLocation(void)
 		    fileName.toUtf8().constData());
 
 		if (!QFile::remove(fileName)) {
-			logErrorNL("Failed deleting database file '%s'.",
+			logErrorNL("Failed to delete database file '%s'.",
 			    fileName.toUtf8().constData());
 			sucessfullyDeleted = false;
 		}
@@ -415,6 +432,34 @@ MessageDbSet::Organisation MessageDbSet::organisation(void) const
 	return m_organisation;
 }
 
+qint64 MessageDbSet::underlyingFileSize(
+    enum MessageDbSet::SizeComputation sc) const
+{
+	qint64 dbSize = 0;
+
+	QMap<QString, MessageDb *>::const_iterator i;
+	for (i = this->begin(); i != this->end(); ++i) {
+		const QString fileName(i.value()->fileName());
+		if (fileName == MessageDb::memoryLocation) {
+			continue;
+		}
+		const QFileInfo fileInfo(fileName);
+		if (fileInfo.exists()) {
+			if (sc == SC_SUM) {
+				dbSize += fileInfo.size();
+			} else if (sc == SC_LARGEST) {
+				if (dbSize < fileInfo.size()) {
+					dbSize = fileInfo.size();
+				}
+			} else {
+				Q_ASSERT(0);
+			}
+		}
+	}
+
+	return dbSize;
+}
+
 QStringList MessageDbSet::fileNames(void) const
 {
 	QStringList fileList;
@@ -485,7 +530,7 @@ MessageDbSet *MessageDbSet::createNew(const QString &locDir,
 			    fileName, organisation);
 
 			if (secondaryKey.isNull()) {
-				logErrorNL("Failed obtaining secondary key from file name '%s'.",
+				logErrorNL("Failed to obtain secondary key from file name '%s'.",
 				    fileName.toUtf8().constData());
 				return NULL;
 			}
@@ -527,7 +572,7 @@ MessageDbSet *MessageDbSet::createNew(const QString &locDir,
 
 			db = dbSet->_accessMessageDb(secondaryKey, false);
 			if (db == NULL) {
-				logErrorNL("Failed opening database file '%s'.",
+				logErrorNL("Failed to open database file '%s'.",
 				    fileName.toUtf8().constData());
 				delete dbSet;
 				return NULL;
@@ -544,7 +589,7 @@ MessageDbSet *MessageDbSet::createNew(const QString &locDir,
 			QString fileName(constructDbFileName(dbSet->m_locDir,
 			    dbSet->m_primaryKey, secKey, dbSet->m_testing,
 			    dbSet->m_organisation));
-			logErrorNL("Failed opening database file '%s'.",
+			logErrorNL("Failed to open database file '%s'.",
 			    fileName.toUtf8().constData());
 			delete dbSet;
 			return NULL;
