@@ -116,7 +116,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadDeliveryInfo(
 
 	isds_error status;
 
-	struct isds_ctx *session = isdsSessions.session(userName);
+	struct isds_ctx *session = globIsdsSessions.session(userName);
 	if (NULL == session) {
 		Q_ASSERT(0);
 		return DM_ERR;
@@ -143,9 +143,9 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadDeliveryInfo(
 	if (IE_SUCCESS != status) {
 		logErrorNL(
 		    "Downloading delivery information returned status %d: '%s'.",
-		    status, isds_strerror(status));
+		    status, isdsStrError(status).toUtf8().constData());
 		error = isds_error(status);
-		longError = isds_long_message(session);
+		longError = isdsLongMessage(session);
 		res = DM_ISDS_ERROR;
 		goto fail;
 	}
@@ -183,7 +183,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadMessage(
 
 	isds_error status;
 
-	struct isds_ctx *session = isdsSessions.session(userName);
+	struct isds_ctx *session = globIsdsSessions.session(userName);
 	if (NULL == session) {
 		Q_ASSERT(0);
 		return DM_ERR;
@@ -198,12 +198,12 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadMessage(
 		/* sent or received message? */
 		if (MSG_RECEIVED == msgDirect) {
 			status = isds_get_signed_received_message(
-			    isdsSessions.session(userName),
+			    globIsdsSessions.session(userName),
 			    QString::number(mId.dmId).toUtf8().constData(),
 			    &message);
 		} else {
 			status = isds_get_signed_sent_message(
-			    isdsSessions.session(userName),
+			    globIsdsSessions.session(userName),
 			    QString::number(mId.dmId).toUtf8().constData(),
 			    &message);
 		}
@@ -211,7 +211,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadMessage(
 		Q_ASSERT(0); /* Only signed messages can be downloaded. */
 		return DM_ERR;
 		/*
-		status = isds_get_received_message(isdsSessions.session(
+		status = isds_get_received_message(globIsdsSessions.session(
 		    userName),
 		    QString::number(mId.dmId).toUtf8().constData(),
 		    &message);
@@ -223,7 +223,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadMessage(
 	if ((IE_SUCCESS != status) ||
 	    (NULL == message) || (NULL == message->envelope)) {
 		error = isds_error(status);
-		longError = isds_long_message(session);
+		longError = isdsLongMessage(session);
 		logErrorNL("Downloading message returned status %d: '%s' '%s'.",
 		    status, error.toUtf8().constData(),
 		    longError.toUtf8().constData());
@@ -319,7 +319,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadMessageAuthor(
 	char * raw_sender_type = NULL;
 	char * sender_name = NULL;
 
-	struct isds_ctx *session = isdsSessions.session(userName);
+	struct isds_ctx *session = globIsdsSessions.session(userName);
 	if (NULL == session) {
 		Q_ASSERT(0);
 		return DM_ERR;
@@ -332,9 +332,9 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::downloadMessageAuthor(
 	if (IE_SUCCESS != status) {
 		logErrorNL(
 		    "Downloading author information returned status %d: '%s'.",
-		    status, isds_strerror(status));
+		    status, isdsStrError(status).toUtf8().constData());
 		error = isds_error(status);
-		longError = isds_long_message(session);
+		longError = isdsLongMessage(session);
 		return DM_ISDS_ERROR;
 	}
 
@@ -357,7 +357,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::markMessageAsDownloaded(
 {
 	debugFuncCall();
 
-	struct isds_ctx *session = isdsSessions.session(userName);
+	struct isds_ctx *session = globIsdsSessions.session(userName);
 	if (NULL == session) {
 		Q_ASSERT(0);
 		return DM_ERR;
@@ -368,7 +368,7 @@ enum TaskDownloadMessage::Result TaskDownloadMessage::markMessageAsDownloaded(
 
 	if (IE_SUCCESS != status) {
 		error = isds_error(status);
-		longError = isds_long_message(session);
+		longError = isdsLongMessage(session);
 		return DM_ISDS_ERROR;
 	}
 	return DM_SUCCESS;
