@@ -65,7 +65,7 @@ public:
 	 * @brief Performs actual message download.
 	 */
 	virtual
-	void run(void);
+	void run(void) Q_DECL_OVERRIDE;
 
 	/*!
 	 * @brief Download delivery info for message.
